@@ -19,11 +19,16 @@ use core::alloc::{GlobalAlloc, Layout};
 use core::ffi::c_void;
 use core::ptr;
 
+#[cfg(target_family = "unix")]
 mod libc;
 
+#[cfg(target_family = "windows")]
+mod win_crt;
+
 /// Global Allocator which hooks into libc to allocate / free memory.
 pub struct LibcAlloc;
 
+#[cfg(target_family = "unix")]
 unsafe impl GlobalAlloc for LibcAlloc {
     #[inline]
     unsafe fn alloc(&self, layout: Layout) -> *mut u8 {
@@ -42,7 +47,7 @@ unsafe impl GlobalAlloc for LibcAlloc {
 
     #[inline]
     unsafe fn alloc_zeroed(&self, layout: Layout) -> *mut u8 {
-        // Unfortuantely, calloc doesn't make any alignment guarantees, so the memory
+        // Unfortunately, calloc doesn't make any alignment guarantees, so the memory
         // has to be manually zeroed-out.
         let ptr = self.alloc(layout);
         if !ptr.is_null() {
@@ -61,3 +66,32 @@ unsafe impl GlobalAlloc for LibcAlloc {
         libc::realloc(ptr as *mut c_void, new_size) as *mut u8
     }
 }
+
+#[cfg(target_family = "windows")]
+unsafe impl GlobalAlloc for LibcAlloc {
+    #[inline]
+    unsafe fn alloc(&self, layout: Layout) -> *mut u8 {
+        win_crt::_aligned_malloc(layout.size(), layout.align()) as *mut u8
+    }
+
+    #[inline]
+    unsafe fn dealloc(&self, ptr: *mut u8, _layout: Layout) {
+        win_crt::_aligned_free(ptr as *mut c_void)
+    }
+
+    #[inline]
+    unsafe fn alloc_zeroed(&self, layout: Layout) -> *mut u8 {
+        // Unfortunately, _aligned_calloc does not exist, so the memory
+        // has to be manually zeroed-out.
+        let ptr = self.alloc(layout);
+        if !ptr.is_null() {
+            ptr::write_bytes(ptr, 0, layout.size());
+        }
+        ptr
+    }
+
+    #[inline]
+    unsafe fn realloc(&self, ptr: *mut u8, layout: Layout, new_size: usize) -> *mut u8 {
+        win_crt::_aligned_realloc(ptr as *mut c_void, new_size, layout.align()) as *mut u8
+    }
+}
